@@ -37,7 +37,8 @@
 RETOBJTYPE CONCAT(CONCAT(NSWPREFIX,get),FUNCOBJENT)(void)
 {
     RETOBJTYPE robj = NULL;
-
+    static int CONCAT(recur_,FUNCNAME) = 0;
+    
     
     if (nswp == NULL)
     {
@@ -45,17 +46,23 @@ RETOBJTYPE CONCAT(CONCAT(NSWPREFIX,get),FUNCOBJENT)(void)
 	setptr = 0;
     }
 
-    if (nswp == NULL)
+    /* We are already executing in this function, or no /etc/nsswitch.conf */
+    if (CONCAT(recur_,FUNCNAME) == 1 || nswp == NULL)
 	return CONCAT(GETPREFIX,FUNCOBJENT)();
 
     if (setptr >= nswp->orderc)
 	return NULL;
     
+    CONCAT(recur_,FUNCNAME) = 1;
+    
     errno = 0;
     do
     {
 	if (nswp->orderl[setptr] == NSWO_RETURN && errno == 0)
+	{
+	    CONCAT(recur_,FUNCNAME) = 0;
 	    return NULL;
+	}
 	
 	if (setflag && setptr == setflag)
 	{
@@ -75,21 +82,22 @@ RETOBJTYPE CONCAT(CONCAT(NSWPREFIX,get),FUNCOBJENT)(void)
 
 #ifdef ENABLE_NIS
 	  case NSWO_NISPLUS:
-	    robj = CONCAT(nis_get,FUNCOBJENT)(NULL);
+	    robj = CONCAT(nis_get,FUNCOBJENT)();
 	    break;
 #endif
 #ifdef ENABLE_YP
 	  case NSWO_NIS:
-	    robj = CONCAT(yp_get,FUNCOBJENT)(NULL);
+	    robj = CONCAT(yp_get,FUNCOBJENT)();
 	    break;
 #endif
 #ifdef ENABLE_DNS
 	  case NSWO_DNS:
-	    robj = CONCAT(dns_get,FUNCOBJENT)(NULL);
+	    robj = CONCAT(dns_get,FUNCOBJENT)();
 	    break;
 #endif
 	}
     } while (robj == NULL && (++setptr < nswp->orderc));
 
+    CONCAT(recur_,FUNCNAME) = 0;
     return robj;
 }
