@@ -33,31 +33,31 @@
 #include "dns_group.h"
 
 
-void dns_setgrent(void *opts)
+void dns_setgrent(void)
 {
 }
 
 
-void dns_endgrent(void *opts)
+void dns_endgrent(void)
 {
 }
 
 
-struct group *dns_getgrent(void *opts)
+struct group *dns_getgrent(void)
 {
     errno = ECONNREFUSED;
     return NULL;
 }
 
 
-struct group *dns_getgrgid(gid_t gid, void *opts)
+struct group *dns_getgrgid(gid_t gid)
 {
     errno = ECONNREFUSED;
     return NULL;
 }
 
 
-struct group *dns_getgrnam(const char *name, void *opts)
+struct group *dns_getgrnam(const char *name)
 {
     errno = ECONNREFUSED;
     return NULL;
