@@ -29,12 +29,11 @@
 #include <sys/types.h>
 #include <netdb.h>
 
-extern void dns_sethostent(int stayopen, void *opts);
-extern void dns_endhostent(void *opts);
-extern struct hostent *dns_gethostent(void *opts);
-extern struct hostent *dns_gethostbyname(const char *name, void *opts);
+extern void dns_sethostent(int stayopen);
+extern void dns_endhostent(void);
+extern struct hostent *dns_gethostent(void);
+extern struct hostent *dns_gethostbyname(const char *name);
 extern struct hostent *dns_gethostbyaddr(const char *addr,
-					 int len, int type,
-					 void *opts);
+					 int len, int type);
 
 #endif
