@@ -29,11 +29,11 @@
 #include <pwd.h>
 #include <sys/types.h>
 
-extern void dns_setpwent(void *opts);
-extern void dns_endpwent(void *opts);
-extern struct passwd *dns_getpwent(void *opts);
-extern struct passwd *dns_getpwuid(uid_t uid, void *opts);
-extern struct passwd *dns_getpwnam(const char *name, void *opts);
+extern void dns_setpwent(void);
+extern void dns_endpwent(void);
+extern struct passwd *dns_getpwent(void);
+extern struct passwd *dns_getpwuid(uid_t uid);
+extern struct passwd *dns_getpwnam(const char *name);
 
 #endif
 
