@@ -30,17 +30,17 @@
 #include "dns_services.h"
 
 
-void dns_setservent(int stayopen, void *opts)
+void dns_setservent(int stayopen)
 {
 }
 
 
-void dns_endservent(void *opts)
+void dns_endservent(void)
 {
 }
 
 
-struct servent *dns_getservent(void *opts)
+struct servent *dns_getservent(void)
 {
     errno = ECONNREFUSED;
     return NULL;
@@ -48,8 +48,7 @@ struct servent *dns_getservent(void *opts)
 
 
 struct servent *dns_getservbyname(const char *name,
-				  const char *protocol,
-				  void *opts)
+				  const char *protocol)
 {
     errno = ECONNREFUSED;
     return NULL;
@@ -57,8 +56,7 @@ struct servent *dns_getservbyname(const char *name,
 
 
 struct servent *dns_getservbyport(int port,
-				  const char *protocol,
-				  void *opts)
+				  const char *protocol)
 {
     errno = ECONNREFUSED;
     return NULL;
