@@ -29,14 +29,12 @@
 #include <sys/types.h>
 #include <netdb.h>
 
-extern void dns_setservent(int stayopen, void *opts);
-extern void dns_endservent(void *opts);
-extern struct servent *dns_getservent(void *opts);
+extern void dns_setservent(int stayopen);
+extern void dns_endservent(void);
+extern struct servent *dns_getservent(void);
 extern struct servent *dns_getservbyname(const char *name,
-					 const char *protocol,
-					 void *opts);
+					 const char *protocol);
 extern struct servent *dns_getservbyport(int port,
-					 const char *protocol,
-					 void *opts);
+					 const char *protocol);
 
 #endif
