@@ -216,6 +216,9 @@ struct spwd *_getspnam(const char *name)
     while ((sp = _getspent()) != NULL &&
 	   strcmp(sp->sp_namp, name) != 0)
 	;
+
+    if (sp == NULL)
+	errno = 0;
     
     return sp;
 }
