@@ -30,32 +30,31 @@
 #include "nis_ethers.h"
 
 
-void nis_setethent(void *opts)
+void nis_setethent(void)
 {
 }
 
 
-void nis_endethent(void *opts)
+void nis_endethent(void)
 {
 }
 
 
-struct ether *nis_getethent(void *opts)
+struct ether *nis_getethent(void)
 {
     errno = ECONNREFUSED;
     return NULL;
 }
 
 
-struct ether *nis_getethbyname(char *name,
-			      void *opts)
+struct ether *nis_getethbyname(const char *name)
 {
     errno = ECONNREFUSED;
     return NULL;
 }
 
 
-struct ether *nis_getethbyaddr(struct ether_addr *addr, void *opts)
+struct ether *nis_getethbyaddr(const struct ether_addr *addr)
 {
     errno = ECONNREFUSED;
     return NULL;
