@@ -30,24 +30,25 @@
 #include "nis_hosts.h"
 
 
-void nis_sethostent(int stayopen, void *opts)
+
+void nis_sethostent(int stayopen)
 {
 }
 
 
-void nis_endhostent(void *opts)
+void nis_endhostent(void)
 {
 }
 
 
-struct hostent *nis_gethostent(void *opts)
+struct hostent *nis_gethostent(void)
 {
     errno = ECONNREFUSED;
     return NULL;
 }
 
 
-struct hostent *nis_gethostbyname(const char *name, void *opts)
+struct hostent *nis_gethostbyname(const char *name)
 {
     errno = ECONNREFUSED;
     return NULL;
@@ -55,8 +56,7 @@ struct hostent *nis_gethostbyname(const char *name, void *opts)
 
 
 struct hostent *nis_gethostbyaddr(const char *addr,
-				  int len, int type,
-				  void *opts)
+				  int len, int type)
 {
     errno = ECONNREFUSED;
     return NULL;
