@@ -45,7 +45,7 @@ static int setflag = 0;
 
 
 #define FUNCNAME getspnam
-#define REQOBJTYPE char *
+#define REQOBJTYPE const char *
 #include "bld/getXXbyYY.h"
 #undef FUNCNAME
 #undef REQOBJTYPE
