@@ -30,12 +30,11 @@
 #include <sys/types.h>
 #include <grp.h>
 
-#define YP_MAX_GROUP_MEMBERS 512
-extern void yp_setgrent(char *opts);
-extern void yp_endgrent(char *opts);
-extern struct group *yp_getgrent(char *opts);
-extern struct group *yp_getgrgid(gid_t gid, char *opts);
-extern struct group *yp_getgrnam(const char *name, char *opts);
+extern void yp_setgrent(void);
+extern void yp_endgrent(void);
+extern struct group *yp_getgrent(void);
+extern struct group *yp_getgrgid(gid_t gid);
+extern struct group *yp_getgrnam(const char *name);
 
 #endif
 
