@@ -30,13 +30,11 @@
 #include <sys/types.h>
 #include <netdb.h>
 
-extern void yp_sethostent(int stayopen, void *opts); 
-/* extern void yp_sethostent(void *opts);  */
-extern void yp_endhostent(void *opts);
-extern struct hostent *yp_gethostent(void *opts);
-extern struct hostent *yp_gethostbyname(const char *name, void *opts);
+extern void yp_sethostent(int stayopen);
+extern void yp_endhostent(void);
+extern struct hostent *yp_gethostent(void);
+extern struct hostent *yp_gethostbyname(const char *name);
 extern struct hostent *yp_gethostbyaddr(const char *addr,
-					 int len, int type,
-					 void *opts);
+					 int len, int type);
 
 #endif
