@@ -29,13 +29,11 @@
 #include <sys/types.h>
 #include <netdb.h>
 
-extern void yp_setprotoent(int stayopen, void *opts);
-extern void yp_endprotoent(void *opts);
-extern struct protoent *yp_getprotoent(void *opts);
-extern struct protoent *yp_getprotobyname(const char *name,
-					  void *opts);
-extern struct protoent *yp_getprotobynumber(int number,
-					    void *opts);
+extern void yp_setprotoent(int stayopen);
+extern void yp_endprotoent(void);
+extern struct protoent *yp_getprotoent(void);
+extern struct protoent *yp_getprotobyname(const char *name);
+extern struct protoent *yp_getprotobynumber(int number);
 
 #endif
 
