@@ -29,15 +29,11 @@
 #include <sys/types.h>
 #include <netdb.h>
 
-extern void yp_setrpcent(int stayopen, void *opts);
-extern void yp_endrpcent(void *opts);
-extern struct rpcent *yp_getrpcent(void *opts);
-extern struct rpcent *yp_getrpcbyname(const char *name,
-				       void *opts);
-extern struct rpcent *yp_getrpcbynumber(int number,
-					 void *opts);
+extern void yp_setrpcent(int stayopen);
+extern void yp_endrpcent(void);
+extern struct rpcent *yp_getrpcent(void);
+extern struct rpcent *yp_getrpcbyname(const char *name);
+extern struct rpcent *yp_getrpcbynumber(int number);
 
 #endif
 
-
-
