@@ -29,17 +29,12 @@
 #include <sys/types.h>
 #include <netdb.h>
 
-extern void yp_setservent(int stayopen, void *opts);
-extern void yp_endservent(void *opts);
-extern struct servent *yp_getservent(void *opts);
+extern void yp_setservent(int stayopen);
+extern void yp_endservent(void);
+extern struct servent *yp_getservent(void);
 extern struct servent *yp_getservbyname(const char *name,
-					const char *protocol,
-					void *opts);
+					const char *protocol);
 extern struct servent *yp_getservbyport(int port,
-					const char *protocol,
-					void *opts);
+					const char *protocol);
 
 #endif
-
-
-
