@@ -45,7 +45,7 @@ main(int argc, char *argv[])
       test = inet_addr(argv[1]);
 
    host = yp_gethostbyaddr((char *) &test, sizeof(unsigned long),
-			   AF_INET, NULL);
+			   AF_INET);
 
     if (host)
 	print_hosts(host);
