@@ -33,12 +33,12 @@ main(int argc, char *argv[])
 {
     struct hostent *host;
 
-    yp_sethostent(1, NULL);
+    yp_sethostent(1);
 
-    while ((host = yp_gethostent(NULL)))
+    while ((host = yp_gethostent()))
 	print_hosts(host);
 
-    yp_endhostent(NULL);
+    yp_endhostent();
     
     exit(0);
 }
