@@ -34,7 +34,7 @@ main(int argc, char *argv[])
     struct hostent *host;
 
 
-    host = yp_gethostbyname(argv[1], NULL);
+    host = yp_gethostbyname(argv[1]);
 
     if (host)
 	print_hosts(host);
