@@ -39,14 +39,12 @@ void print_network(struct netent *net)
 {
    int member_index;
       
-   printf("%s\t%s\t(%04x) %s\t",
+   printf("%s\t%s\t(%04lx) %s\t",
 	  net->n_name,
 	  net->n_addrtype == AF_INET ? "AF_INET" : "UNKNOWN",
 	  net->n_net,
 	  inet_ntoa(inet_makeaddr(net->n_net,0)));
    
-
-   
    for (member_index = 0 ;
 	net->n_aliases && net->n_aliases[member_index] ;
 	++member_index)
@@ -55,6 +53,5 @@ void print_network(struct netent *net)
       else
          printf(",%s", net->n_aliases[member_index]);
    printf("\n");
-	     
 }
 
