@@ -74,6 +74,29 @@ extern int yp_next(const char *indomain,
 		   char **outval,
 		   int *outvallen);
 
+struct ypall_callback
+{
+    int (*foreach)(int instatus,
+		   char *key,
+		   int keylen,
+		   char *val,
+		   int vallen,
+		   char *data);
+    char *data;
+};
+
+extern int yp_all(char *indomain,
+		  char *inmap,
+		  struct ypall_callback *incbp);
+
+extern int yp_order(char *indomain,
+		    char *inmap,
+		    int *outorder);
+
+extern int yp_master(char *indomain,
+		     char *inmap,
+		     char **outname);
+
 extern char *yperr_string(int ecode);
 
 extern int ypprot_err(int ecode);
