@@ -209,8 +209,8 @@ static void *do_ypcall(const char *domain,
 
     if ((*ecode = yp_setup()) != 0)
 	return NULL;
+
     clh = ypconf_domain2client(domain, NULL, &address);
-    
     if (!clh)
     {
 	*ecode = YPERR_DOMAIN;
@@ -336,10 +336,10 @@ int yp_first(const char *indomain,
 					 &code);
     if (ypres == NULL)
 	return code;
-    
+
     if (ypres->stat != YP_TRUE)
 	return ypprot_err(ypres->stat);
-    
+
 /* XXX What's going on here??? outval and outkey arrive in the wrong order! */
 #ifdef HAVE_BUGGY_YP_X
     *outval = xstrdup(ypres->key.keydat_val, ypres->key.keydat_len);
@@ -354,7 +354,7 @@ int yp_first(const char *indomain,
     *outval = xstrdup(ypres->val.valdat_val, ypres->val.valdat_len);
     *outvallen = ypres->val.valdat_len;
 #endif
-    
+
     return 0;
 }
 
@@ -406,4 +406,146 @@ int yp_next(const char *indomain,
     return 0;
 }
 
+
+
+int yp_bind(char *indomain)
+{
+    CLIENT *clh;
+    char *address;
+    int ecode;
+
+    if ((ecode = yp_setup()) != 0)
+	return ecode;
+
+    clh = ypconf_domain2client(indomain, NULL, &address);
+    if (clh)
+	return 0;
+    else
+	return YPERR_DOMAIN;
+}
+
+void yp_unbind(char *indomain)
+{
+    if (yp_setup())
+	return;
+
+    if (ypconf_unbinddomain(indomain) < 0)
+	return;
+}
+
+
+/*
+** XXXX FIXME! Should be changed to use a TCP link to transfer
+** the whole map and not this kludgy emulation...
+*/
+int yp_all(char *indomain,
+	   char *inmap,
+	   struct ypall_callback *incbp)
+{
+    int code;
+    char *key;
+    int keylen;
+    char *val;
+    int vallen;
+
+
+    key = NULL;
+    val = NULL;
+
+    code = yp_first(indomain, inmap,
+		    &key, &keylen,
+		    &val, &vallen);
+
+    while (code == 0)
+    {
+	char *savekey = key;
+	
+	if ((*incbp->foreach)(code,
+			      key, keylen,
+			      val, vallen,
+			      incbp->data) != 0)
+	{
+	    free(key);
+	    free(val);
+
+	    return 0;
+	}
+	
+
+	free(val);
+	
+	key = NULL;
+	val = NULL;
+	
+	code = yp_next(indomain, inmap,
+		       savekey, keylen,
+		       &key, &keylen,
+		       &val, &vallen);
+
+	free(savekey);
+    }
+
+    if (key)
+	free(key);
+    if (val)
+	free(val);
+
+    return (code == YPERR_NOMORE ? 0 : code);
+}
+
+int yp_order(char *indomain,
+	     char *inmap,
+	     int *outorder)
+{
+    ypreq_nokey ypreq;
+    ypresp_order *ypres;
+    int code;
+    
+
+    ypreq.domain = (char *) indomain;
+    ypreq.map = (char *) inmap;
+
+    ypres = (ypresp_order *) do_ypcall(indomain,
+				       (void * (*)(void *req, CLIENT *clh))
+				       &ypproc_order_2, &ypreq,
+				       &code);
+    if (ypres == NULL)
+	return code;
+    
+    if (ypres->stat != YP_TRUE)
+	return ypprot_err(ypres->stat);
+    
+    *outorder = ypres->ordernum;
+    
+    return 0;
+}
+
+int yp_master(char *indomain,
+	      char *inmap,
+	      char **outname)
+{
+    ypreq_nokey ypreq;
+    ypresp_master *ypres;
+    int code;
+    
+
+    ypreq.domain = (char *) indomain;
+    ypreq.map = (char *) inmap;
+
+    ypres = (ypresp_master *) do_ypcall(indomain,
+					(void * (*)(void *req, CLIENT *clh))
+					&ypproc_master_2, &ypreq,
+					&code);
+    if (ypres == NULL)
+	return code;
+    
+    if (ypres->stat != YP_TRUE)
+	return ypprot_err(ypres->stat);
+    
+    *outname = strdup(ypres->peer);
+    
+    return 0;
+}
+
+
 #endif /* ENABLE_YPEMU */
